@@ -3,13 +3,13 @@ package Net::DNS::Parameters;
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2024-04-09)
+##	(last updated 2024-10-24)
 ##
 ################################################
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: Parameters.pm 1972 2024-04-21 08:13:19Z willem $)[2];
+our $VERSION = (qw$Id: Parameters.pm 1993 2024-11-07 14:06:53Z willem $)[2];
 
 use integer;
 use Carp;
@@ -125,6 +125,7 @@ my @typebyname = (
 	LP	   => 107,					# RFC6742
 	EUI48	   => 108,					# RFC7043
 	EUI64	   => 109,					# RFC7043
+	NXNAME	   => 128,					# draft-ietf-dnsop-compact-denial-of-existence-04
 	TKEY	   => 249,					# RFC2930
 	TSIG	   => 250,					# RFC8945
 	IXFR	   => 251,					# RFC1995
@@ -137,8 +138,11 @@ my @typebyname = (
 	AVC	   => 258,					#
 	DOA	   => 259,					# draft-durand-doa-over-dns
 	AMTRELAY   => 260,					# RFC8777
-	RESINFO	   => 261,					# draft-ietf-add-resolver-info-06
-	TA	   => 32768,					# http://cameo.library.cmu.edu/ http://www.watson.org/~weiler/INI1999-19.pdf
+	RESINFO	   => 261,					# RFC9606
+	WALLET	   => 262,					#
+	CLA	   => 263,					# draft-johnson-dns-ipn-cla-07
+	IPN	   => 264,					# draft-johnson-dns-ipn-cla-07
+	TA	   => 32768,					# http://www.watson.org/~weiler/INI1999-19.pdf
 	DLV	   => 32769,					# RFC8749 RFC4431
 	);
 our %typebyval = reverse( TYPE0 => 0, @typebyname );
@@ -208,7 +212,8 @@ my @ednsoptionbyname = (
 	'EXTENDED-ERROR' => 15,					# RFC8914
 	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
 	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
-	'REPORT-CHANNEL' => 18,					# RFC-ietf-dnsop-dns-error-reporting-08
+	'REPORT-CHANNEL' => 18,					# RFC9567
+	ZONEVERSION	 => 19,					# RFC9660
 	'UMBRELLA-IDENT' => 20292,				# https://developer.cisco.com/docs/cloud-security/#!integrating-network-devic
 	DEVICEID	 => 26946,				# https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-s
 	);
@@ -285,6 +290,7 @@ my @dnserrorbyval = (
 	27 => 'Unsupported NSEC3 Iterations Value',		# RFC9276
 	28 => 'Unable to conform to policy',			# draft-homburg-dnsop-codcp-00
 	29 => 'Synthesized',					# https://github.com/PowerDNS/pdns/pull/12334
+	30 => 'Invalid Query Type',				# draft-ietf-dnsop-compact-denial-of-existence-04
 	);
 our %dnserrorbyval = @dnserrorbyval;
 
