@@ -2,7 +2,7 @@ package Net::DNS::RR::TLSA;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: TLSA.pm 1814 2020-10-14 21:49:16Z willem $)[2];
+our $VERSION = (qw$Id: TLSA.pm 1896 2023-01-30 12:59:25Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -20,8 +20,7 @@ use constant BABBLE => defined eval { require Digest::BubbleBabble };
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $next = $offset + $self->{rdlength};
 
@@ -50,51 +49,46 @@ sub _format_rdata {			## format rdata portion of RR string.
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->usage(shift);
-	$self->selector(shift);
-	$self->matchingtype(shift);
-	$self->cert(@_);
+	for (qw(usage selector matchingtype)) { $self->$_( shift @argument ) }
+	$self->cert(@argument);
 	return;
 }
 
 
 sub usage {
-	my $self = shift;
-
-	$self->{usage} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{usage} = 0 + $_ }
 	return $self->{usage} || 0;
 }
 
 
 sub selector {
-	my $self = shift;
-
-	$self->{selector} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{selector} = 0 + $_ }
 	return $self->{selector} || 0;
 }
 
 
 sub matchingtype {
-	my $self = shift;
-
-	$self->{matchingtype} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{matchingtype} = 0 + $_ }
 	return $self->{matchingtype} || 0;
 }
 
 
 sub cert {
-	my $self = shift;
-	return unpack "H*", $self->certbin() unless scalar @_;
-	return $self->certbin( pack "H*", join "", map { /^"*([\dA-Fa-f]*)"*$/ || croak("corrupt hex"); $1 } @_ );
+	my ( $self, @value ) = @_;
+	return unpack "H*", $self->certbin() unless scalar @value;
+	my @hex = map { /^"*([\dA-Fa-f]*)"*$/ || croak("corrupt hex"); $1 } @value;
+	return $self->certbin( pack "H*", join "", @hex );
 }
 
 
 sub certbin {
-	my $self = shift;
-
-	$self->{certbin} = shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{certbin} = $_ }
 	return $self->{certbin} || "";
 }
 
@@ -204,7 +198,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -221,6 +215,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC6698
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC6698|https://tools.ietf.org/html/rfc6698>
 
 =cut
